package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.MqttSensorDevice;
import com.shzg.project.worn.service.IMqttSensorDeviceService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * MQTT设备Controller
 * 
 * @author shzg
 * @date 2026-04-01
 */
@RestController
@RequestMapping("/worn/mqttDevice")
public class MqttSensorDeviceController extends BaseController
{
    @Autowired
    private IMqttSensorDeviceService mqttSensorDeviceService;

    /**
     * 查询MQTT设备列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttDevice:list')")
    @GetMapping("/list")
    public TableDataInfo list(MqttSensorDevice mqttSensorDevice)
    {
        startPage();
        List<MqttSensorDevice> list = mqttSensorDeviceService.selectMqttSensorDeviceList(mqttSensorDevice);
        return getDataTable(list);
    }

    /**
     * 导出MQTT设备列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttDevice:export')")
    @Log(title = "MQTT设备", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MqttSensorDevice mqttSensorDevice)
    {
        List<MqttSensorDevice> list = mqttSensorDeviceService.selectMqttSensorDeviceList(mqttSensorDevice);
        ExcelUtil<MqttSensorDevice> util = new ExcelUtil<MqttSensorDevice>(MqttSensorDevice.class);
        util.exportExcel(response, list, "MQTT设备数据");
    }

    /**
     * 获取MQTT设备详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttDevice:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mqttSensorDeviceService.selectMqttSensorDeviceById(id));
    }

    /**
     * 新增MQTT设备
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttDevice:add')")
    @Log(title = "MQTT设备", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MqttSensorDevice mqttSensorDevice)
    {
        return toAjax(mqttSensorDeviceService.insertMqttSensorDevice(mqttSensorDevice));
    }

    /**
     * 修改MQTT设备
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttDevice:edit')")
    @Log(title = "MQTT设备", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MqttSensorDevice mqttSensorDevice)
    {
        return toAjax(mqttSensorDeviceService.updateMqttSensorDevice(mqttSensorDevice));
    }

    /**
     * 删除MQTT设备
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttDevice:remove')")
    @Log(title = "MQTT设备", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mqttSensorDeviceService.deleteMqttSensorDeviceByIds(ids));
    }
}
